--
-- BottleDrinkEvent
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

BottleDrinkEvent = {};

local BottleDrinkEvent_mt = Class(BottleDrinkEvent);


function BottleDrinkEvent:new(params, mission, customMt)
    local mt = customMt;
    if mt == nil then
        mt = BottleDrinkEvent_mt;
    end;
    local self = {};
    setmetatable(self, mt);

    local numBottles = params["numBottles"];
    if numBottles == nil then
        return nil;
    end;
    self.numBottles = math.floor(tonumber(numBottles));

    self.level = 0;
    self.isTriggered = false;

    local isMissionGoal = params["isMissionGoal"];
    if isMissionGoal ~= nil and isMissionGoal == "true" then
        mission:addMissionGoalEvent(self);
    end;
    self.numBottlesPicked = 0;
    mission:addPickupListener(self);

    return self;
end;

function BottleDrinkEvent:delete()
end;

function BottleDrinkEvent:reset()
    self.isTriggered = false;
    self.numBottlesPicked = 0;
end;

function BottleDrinkEvent:update(dt, mission)
    self.level = math.min(self.numBottlesPicked / self.numBottles, 1);

    if self.level == 1 then
        if not self.isTriggered then
            print("has event drink");
            self.isTriggered = true;
            mission:setEventTriggered(self, true);
        end;
    else
        if self.isTriggered then
            self.isTriggered = false;
            mission:setEventTriggered(self, false);
        end;
    end;

end;

-- this is called as soon this event is set to be triggered and all preconditions are fulfilled
function BottleDrinkEvent:onTriggered(isTriggered, mission)
    -- nothing to do here
end;

function BottleDrinkEvent:getGoalLevel()
    return self.level;
end;

-- pickup listener callback
-- this is called whenever an object is picked up
function BottleDrinkEvent:onPickup(object)
    if object:isa(Bottle) then
        self.numBottlesPicked = self.numBottlesPicked+1;
    end;
end;
